| datasim02 | R Documentation |
A simulated dataset consisting of discretely observed trajectories generated from a one-dimensional Wiener diffusion model with random effects in the drift term.
data(datasim02)
A data frame with observations from multiple experimental units and the following variables:
tObservation time.
unitUnit identifier.
YObserved process value.
The data were generated from the stochastic differential equation
dY_k(t) = a_k \sin(\pi t)\,dt + \sigma\,dW_k(t),
where the unit-specific random effects follow a normal distribution
a_k \sim \mathcal{N}(10, 3),
and the diffusion variance is given by \sigma^2 = 50.
The integrated drift used for simulation is given by
\mu_{\Delta}(a_k, t_i, t_{i-1})
=
\frac{a_k}{\pi}
\left\{
\cos(\pi t_{i-1}) - \cos(\pi t_i)
\right\}.
The process was simulated for K = 50 units, each observed at
n = 200 equally spaced time points, with initial condition
Y_{k0} = 1.
A data frame with simulated data.
Simulated data generated for illustrative purposes.
None.
data(datasim02)
plot_paths(df = datasim02)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.